@@ -34,7 +34,9 @@
 #pragma GCC poison PETSC_PETSC_HAVE_MEMMOVE
 #pragma GCC poison PETSC_PETSC_HAVE_MKSTEMP
 #pragma GCC poison PETSC_PETSC_HAVE_MPIUNI
+#pragma GCC poison PETSC_PETSC_HAVE_MPI_REDUCE_LOCAL
 #pragma GCC poison PETSC_PETSC_HAVE_OPENBLAS
+#pragma GCC poison PETSC_PETSC_HAVE_OPENBLAS_SET_NUM_THREADS
 #pragma GCC poison PETSC_PETSC_HAVE_OPENMP
 #pragma GCC poison PETSC_PETSC_HAVE_O_BINARY
 #pragma GCC poison PETSC_PETSC_HAVE_PACKAGES
